@@ -1,5 +1,5 @@
 # Parallel Python Software: http://www.parallelpython.com
-# Copyright (c) 2005-2010, Vitalii Vanovschi
+# Copyright (c) 2005-2011, Vitalii Vanovschi
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -44,8 +44,8 @@ import pptransport
 import ppauto
 import ppcommon
 
-copyright = "Copyright (c) 2005-2010 Vitalii Vanovschi. All rights reserved"
-version = "1.6.0"
+copyright = "Copyright (c) 2005-2011 Vitalii Vanovschi. All rights reserved"
+version = "1.6.1"
 
 # Reconnect persistent rworkers in seconds.
 RECONNECT_WAIT_TIME = 5
@@ -130,16 +130,11 @@ class _Task(object):
 class _Worker(object):
     """Local worker class
     """
-    command = "\"" + sys.executable + "\" -u \"" \
-            + os.path.dirname(os.path.abspath(__file__))\
-            + os.sep + "ppworker.py\""
+    command = [sys.executable, "-u",
+            os.path.dirname(os.path.abspath(__file__))
+            + os.sep + "ppworker.py"]
 
-    if sys.platform.startswith("win"):
-        # workargound for windows
-        command = "\"" + command + "\""
-    else:
-        # do not show "Borken pipe message" at exit on unix/linux
-        command += " 2>/dev/null"
+    command.append("2>/dev/null")
 
     def __init__(self, restart_on_free, pickle_proto):
         """Initializes local worker"""
@@ -152,7 +147,7 @@ class _Worker(object):
         if _USE_SUBPROCESS:
             proc = subprocess.Popen(self.command, stdin=subprocess.PIPE, \
                     stdout=subprocess.PIPE, stderr=subprocess.PIPE, \
-                    shell=True)
+                    shell=False)
             self.t = pptransport.CPipeTransport(proc.stdout, proc.stdin)
         else:
             self.t = pptransport.CPipeTransport(\
@@ -299,7 +294,7 @@ class Server(object):
            secret - passphrase for network connections, if omitted a default
                    passphrase will be used. It's highly recommended to use a
                    custom passphrase for all network connections.
-           restart - wheather to restart worker process after each task completion
+           restart - whether to restart worker process after each task completion
            proto - protocol number for pickle module
 
            With ncpus = 1 all tasks are executed consequently
@@ -312,6 +307,8 @@ class Server(object):
 
         self.logger = logging.getLogger('pp')
         self.logger.info("Creating server instance (pp-" + version+")")
+        self.logger.info("Running on Python %s %s", sys.version.split(" ")[0],
+                sys.platform)
         self.__tid = 0
         self.__active_tasks = 0
         self.__active_tasks_lock = threading.Lock()
@@ -413,6 +410,9 @@ class Server(object):
         if not isinstance(callbackargs, tuple):
             raise TypeError("callbackargs argument must be a tuple")
 
+        if globals is not None and not isinstance(globals, dict):
+            raise TypeError("globals argument must be a dictionary")
+
         for module in modules:
             if not isinstance(module, types.StringType):
                 raise TypeError("modules argument must be a list of strings")
