@@ -1,5 +1,5 @@
 # Parallel Python Software: http://www.parallelpython.com
-# Copyright (c) 2005-2010, Vitalii Vanovschi
+# Copyright (c) 2005-2011, Vitalii Vanovschi
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -36,8 +36,8 @@ import threading
 
 import ppcommon
 
-copyright = "Copyright (c) 2005-2010 Vitalii Vanovschi. All rights reserved"
-version = "1.6.0"
+copyright = "Copyright (c) 2005-2011 Vitalii Vanovschi. All rights reserved"
+version = "1.6.1"
 
 # broadcast every 10 sec
 BROADCAST_INTERVAL = 10
@@ -100,7 +100,7 @@ class Discover(object):
                 hostid = host + ":" + str(self.broadcast_addr[1])
                 self.base.logger.debug("Discovered host (%s, %i) message=%c"
                         % (remote_address + (message[0], )))
-                if hostid not in self.base.autopp_list and self.isclient \
+                if not self.base.autopp_list.get(hostid, 0) and self.isclient \
                         and message[0] == 'S':
                     self.base.logger.debug("Connecting to host %s" % (hostid, ))
                     ppcommon.start_thread("ppauto_connect1",  self.base.connect1,
