@@ -1,5 +1,5 @@
 # Parallel Python Software: http://www.parallelpython.com
-# Copyright (c) 2005-2010, Vitalii Vanovschi
+# Copyright (c) 2005-2011, Vitalii Vanovschi
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -34,8 +34,8 @@ import struct
 import socket
 import logging
 
-copyright = "Copyright (c) 2005-2010 Vitalii Vanovschi. All rights reserved"
-version = "1.6.0"
+copyright = "Copyright (c) 2005-2011 Vitalii Vanovschi. All rights reserved"
+version = "1.6.1"
 
 TRANSPORT_SOCKET_TIMEOUT = 60
 
@@ -130,10 +130,27 @@ class PipeTransport(Transport):
         self.w.flush()
 
     def receive(self, preprocess=None):
-        size_packed = self.r.read(struct.calcsize("!Q"))
-        msg_len = struct.unpack("!Q", size_packed)[0]
-        msg = self.r.read(msg_len)
-        return map(preprocess, (msg, ))[0]
+        e_size = struct.calcsize("!Q")
+        r_size = 0
+        data = ""
+        while r_size < e_size:
+            msg = self.r.read(e_size-r_size)
+            if msg == "":
+                raise RuntimeError("Communication pipe read error")
+            r_size += len(msg)
+            data += msg
+        e_size = struct.unpack("!Q", data)[0]
+
+        r_size = 0
+        data = ""
+        while r_size < e_size:
+            msg = self.r.read(e_size-r_size)
+            if msg == "":
+                raise RuntimeError("Communication pipe read error")
+            r_size += len(msg)
+            data += msg
+
+        return map(preprocess, (data, ))[0]
 
     def close(self):
         self.w.close()
