@@ -1,5 +1,5 @@
 # Parallel Python Software: http://www.parallelpython.com
-# Copyright (c) 2005-2010, Vitalii Vanovschi
+# Copyright (c) 2005-2011, Vitalii Vanovschi
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -35,30 +35,24 @@ import StringIO
 import cPickle as pickle
 import pptransport
 
-copyright = "Copyright (c) 2005-2010 Vitalii Vanovschi. All rights reserved"
-version = "1.6.0"
-
-
-def import_module(name):
-    mod = __import__(name)
-    components = name.split('.')
-    for comp in components[1:]:
-        mod = getattr(mod, comp)
-    return mod
+copyright = "Copyright (c) 2005-2011 Vitalii Vanovschi. All rights reserved"
+version = "1.6.1"
 
 
 def preprocess(msg):
     fname, fsources, imports = pickle.loads(msg)
     fobjs = [compile(fsource, '<string>', 'exec') for fsource in fsources]
     for module in imports:
-        try:
-            globals()[module.split('.')[0]] = import_module(module)
+        try:            
+            if not module.startswith("from ") and not module.startswith("import "):
+                module = "import " + module
+            exec module
+            globals().update(locals())
         except:
             print "An error has occured during the module import"
             sys.excepthook(*sys.exc_info())
     return fname, fobjs
 
-
 class _WorkerProcess(object):
 
     def __init__(self):
@@ -76,7 +70,6 @@ class _WorkerProcess(object):
         try:
             #execution cycle
             while 1:
-
                 __fname, __fobjs = self.t.creceive(preprocess)
 
                 __sargs = self.t.receive()
